import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS AppSync.
 *
 * @stability stable
 */
export interface AppsyncResolverConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#api_id AppsyncResolver#api_id}.
     *
     * @stability stable
     */
    readonly apiId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#data_source AppsyncResolver#data_source}.
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#field AppsyncResolver#field}.
     *
     * @stability stable
     */
    readonly field: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#kind AppsyncResolver#kind}.
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#request_template AppsyncResolver#request_template}.
     *
     * @stability stable
     */
    readonly requestTemplate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#response_template AppsyncResolver#response_template}.
     *
     * @stability stable
     */
    readonly responseTemplate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#type AppsyncResolver#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * caching_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#caching_config AppsyncResolver#caching_config}
     *
     * @stability stable
     */
    readonly cachingConfig?: AppsyncResolverCachingConfig;
    /**
     * pipeline_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#pipeline_config AppsyncResolver#pipeline_config}
     *
     * @stability stable
     */
    readonly pipelineConfig?: AppsyncResolverPipelineConfig;
}
/**
 * @stability stable
 */
export interface AppsyncResolverCachingConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#caching_keys AppsyncResolver#caching_keys}.
     *
     * @stability stable
     */
    readonly cachingKeys?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#ttl AppsyncResolver#ttl}.
     *
     * @stability stable
     */
    readonly ttl?: number;
}
export declare function appsyncResolverCachingConfigToTerraform(struct?: AppsyncResolverCachingConfigOutputReference | AppsyncResolverCachingConfig): any;
/**
 * @stability stable
 */
export declare class AppsyncResolverCachingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AppsyncResolverCachingConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AppsyncResolverCachingConfig | undefined);
    private _cachingKeys?;
    /**
     * @stability stable
     */
    get cachingKeys(): string[];
    /**
     * @stability stable
     */
    set cachingKeys(value: string[]);
    /**
     * @stability stable
     */
    resetCachingKeys(): void;
    /**
     * @stability stable
     */
    get cachingKeysInput(): string[] | undefined;
    private _ttl?;
    /**
     * @stability stable
     */
    get ttl(): number;
    /**
     * @stability stable
     */
    set ttl(value: number);
    /**
     * @stability stable
     */
    resetTtl(): void;
    /**
     * @stability stable
     */
    get ttlInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface AppsyncResolverPipelineConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#functions AppsyncResolver#functions}.
     *
     * @stability stable
     */
    readonly functions?: string[];
}
export declare function appsyncResolverPipelineConfigToTerraform(struct?: AppsyncResolverPipelineConfigOutputReference | AppsyncResolverPipelineConfig): any;
/**
 * @stability stable
 */
export declare class AppsyncResolverPipelineConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AppsyncResolverPipelineConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AppsyncResolverPipelineConfig | undefined);
    private _functions?;
    /**
     * @stability stable
     */
    get functions(): string[];
    /**
     * @stability stable
     */
    set functions(value: string[]);
    /**
     * @stability stable
     */
    resetFunctions(): void;
    /**
     * @stability stable
     */
    get functionsInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver aws_appsync_resolver}.
 *
 * @stability stable
 */
export declare class AppsyncResolver extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver aws_appsync_resolver} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppsyncResolverConfig);
    private _apiId?;
    /**
     * @stability stable
     */
    get apiId(): string;
    /**
     * @stability stable
     */
    set apiId(value: string);
    /**
     * @stability stable
     */
    get apiIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    resetDataSource(): void;
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _field?;
    /**
     * @stability stable
     */
    get field(): string;
    /**
     * @stability stable
     */
    set field(value: string);
    /**
     * @stability stable
     */
    get fieldInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    resetKind(): void;
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _requestTemplate?;
    /**
     * @stability stable
     */
    get requestTemplate(): string;
    /**
     * @stability stable
     */
    set requestTemplate(value: string);
    /**
     * @stability stable
     */
    resetRequestTemplate(): void;
    /**
     * @stability stable
     */
    get requestTemplateInput(): string | undefined;
    private _responseTemplate?;
    /**
     * @stability stable
     */
    get responseTemplate(): string;
    /**
     * @stability stable
     */
    set responseTemplate(value: string);
    /**
     * @stability stable
     */
    resetResponseTemplate(): void;
    /**
     * @stability stable
     */
    get responseTemplateInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _cachingConfig;
    /**
     * @stability stable
     */
    get cachingConfig(): AppsyncResolverCachingConfigOutputReference;
    /**
     * @stability stable
     */
    putCachingConfig(value: AppsyncResolverCachingConfig): void;
    /**
     * @stability stable
     */
    resetCachingConfig(): void;
    /**
     * @stability stable
     */
    get cachingConfigInput(): AppsyncResolverCachingConfig | undefined;
    private _pipelineConfig;
    /**
     * @stability stable
     */
    get pipelineConfig(): AppsyncResolverPipelineConfigOutputReference;
    /**
     * @stability stable
     */
    putPipelineConfig(value: AppsyncResolverPipelineConfig): void;
    /**
     * @stability stable
     */
    resetPipelineConfig(): void;
    /**
     * @stability stable
     */
    get pipelineConfigInput(): AppsyncResolverPipelineConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
